==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Kattintson a tálcaikonra
vagy nyomja le a gyorsbillentyűt ismét a felvétel megállításához</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Rögzítés</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Képernyőkép</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Képernyőrögzítő</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>A mentés nem sikerült. Kérjük mentse el a saját mappájába.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>A képernyőkép készítése befejeződött</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Terület kiválasztása</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Mentve ide: %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Mellőzés</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Vágólap</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>A képernyőrögzítő fájl mentése, kérjük várjon ...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Mivel az ablakok effektezése le van tiltva a folyamat során, a felvételt le kell állítani</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Képernyőkép</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>A felvétel befejeződött</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Mentve ide: %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Felvétel</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>A képernyő rögzítése %1 másodperc múlva indul</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Írja be ide a szöveget</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Indítás/Képernyőkép</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Kilépés / Mentés</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Rajzolás</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Méret beállítások</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Gyorsindítás</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Ablak képernyőkép</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Késleltetett képernyőkép</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Teljes képernyőkép</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Négyszög</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipszis</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Vonal</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Ceruza</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Növelje a magasságot fent</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Növelje a magasságot lent</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Növelje a szélességet bal oldalt</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Növelje a szélességet jobb oldalt</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Csökkentse a magasságot fent</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Csökkentse a magasságot lent</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Csökkentse a szélességet bal oldalt</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Csökkentse a szélességet jobb oldalt</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Gyorsbillentyűk megjelenítése</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Hang</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Billentyűleütés</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Felvétel megkezdése</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Indítás/Felvétel</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Egér</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Elmosás</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Hang bekapcsolása</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Rendszer hangok</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Hang kikapcsolása</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>A billentyűleütés megjelenítése</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>A billentyűleütés elrejtése</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webkamera bekapcsolása</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webkamera kikapcsolása</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Kattintás megjelenítése</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formátum:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Négyszög</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipszis</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Vonal</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Nyíl</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Ceruza</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Mentés ide</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Képek</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formátum</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Vágólap</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mutató megjelenítése</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Egér</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mutató megjelenítése</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>A jobb videoeffektus elérése érdekében állítsa be a felvételi területet %1*%2</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Felvételek</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Kattintson a tálcaikonra
vagy nyomja le a gyorsbillentyűt ismét a felvétel megállításához</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Felvétel közben ne forgassa el a képernyőjét</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Rögzítés</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Képernyőkép</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Képernyőrögzítő</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>A mentés nem sikerült. Kérjük mentse el a saját mappájába.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>A képernyőkép készítése befejeződött</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Terület kiválasztása</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Mentve ide: %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Mellőzés</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Vágólap</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>A képernyőrögzítő fájl mentése, kérjük várjon ...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Mivel az ablakok effektezése le van tiltva a folyamat során, a felvételt le kell állítani</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Képernyőkép</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>A képernyőkép mentve az albumba</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>A képernyőkép készítése sikertelen</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Görgethető képernyőkép</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>A felvétel befejeződött</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Mentve ide: %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Felvétel</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>A képernyő rögzítése %1 másodperc múlva indul</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Segítséget kaphat</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>A folyamatos képernyőkép készítése sikertelen.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Elérte a görgetési terület alját</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Elérte a maximális hosszúságot</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>Állítsa be a rögzítési területet</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Görgessen az egérgörgőn, vagy kattintson rá, hogy görgethető képernyőképet készítsen</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Lassítson a görgetési sebességen</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Érvénytelen terület, kattintson rá</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Írja be ide a szöveget</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Indítás/Képernyőkép</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Kilépés / Mentés</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Méret beállítások</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Gyorsindítás</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Ablak képernyőkép</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Késleltetett képernyőkép</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Teljes képernyőkép</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Négyszög</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipszis</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Vonal</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Ceruza</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Növelje a magasságot fent</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Növelje a magasságot lent</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Növelje a szélességet bal oldalt</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Növelje a szélességet jobb oldalt</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Csökkentse a magasságot fent</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Csökkentse a magasságot lent</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Csökkentse a szélességet bal oldalt</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Csökkentse a szélességet jobb oldalt</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Gyorsbillentyűk megjelenítése</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Hang</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Billentyűleütés</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Felvétel megkezdése</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Indítás/Felvétel</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Egér</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Eszközök</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Szöveg kivonat</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Görgethető képernyőkép</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Képernyőképek rögzítése</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Elmosás</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Hang bekapcsolása</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Rendszer hangok</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Hang kikapcsolása</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>A billentyűleütés megjelenítése</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>A billentyűleütés elrejtése</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webkamera bekapcsolása</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webkamera kikapcsolása</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Kattintás megjelenítése</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formátum:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Négyszög</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipszis</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Vonal</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Nyíl</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Ceruza</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Mentés ide</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Képek</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formátum</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Vágólap</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mutató megjelenítése</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Egér</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mutató megjelenítése</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Szöveg kivonat</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Görgethető képernyőkép</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Képernyőképek rögzítése</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>A jobb videoeffektus elérése érdekében állítsa be a felvételi területet %1*%2</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>A képernyőfelvétel jelenleg nem támogatott</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
</context>
</TS>
